@@ -1,4 +1,4 @@
-/* $Id: dict.c,v 1.19 2002/05/11 21:04:27 gman Exp $ */
+/* $Id: dict.c,v 1.19.4.1 2003/05/14 14:48:25 utx Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -76,10 +76,11 @@ void dict_res_destroy (dict_res_t *res)
 
 static int dict_write (dict_context_t *context, GString *str) 
 {
-    int res, amt;
-  
+    int res;
+    gsize amt;
+
     res = g_io_channel_write(context->channel, str->str, str->len, &amt);
-    
+
     if (res != G_IO_ERROR_NONE)
 	return -1;
     else
@@ -123,7 +124,8 @@ dict_command_done (dict_command_t *command)
 static int 
 cycle_buffer (dict_context_t *context) 
 {
-    int amt_read, res;
+    gsize amt_read;
+    int res;
     GIOChannelError chanerr;
 
     if (!context->channel)
@@ -150,7 +152,7 @@ cycle_buffer (dict_context_t *context)
 		return -1;
         } else if (res != G_IO_ERROR_NONE)
 	    return -1;
-        
+
         context->write_ptr += amt_read;
         return 0;
     }
